@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate;
-$App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate::VERSION = '0.17';
+$App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate::VERSION = '0.18';
 # ABSTRACT: MsgMaker class for L<App::SpreadRevolutionaryDate> to build message with revolutionary date
 
 use Moose;
@@ -21,18 +21,22 @@ use App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate::Calendar;
 use Locale::TextDomain 'App-SpreadRevolutionaryDate';
 use namespace::autoclean;
 
+has '+locale' => (
+  default => 'fr',
+);
+
 has 'acab' => (
-    is  => 'ro',
-    isa => 'Bool',
-    required => 1,
-    default => 0,
+  is  => 'ro',
+  isa => 'Bool',
+  required => 1,
+  default => 0,
 );
 
 has 'wikipedia_link' => (
-    is  => 'ro',
-    isa => 'Bool',
-    required => 1,
-    default => 1,
+  is  => 'ro',
+  isa => 'Bool',
+  required => 1,
+  default => 1,
 );
 
 around BUILDARGS => sub {
@@ -97,7 +101,7 @@ App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate - MsgMaker class for L
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 METHODS
 
